package com.bonus.material.settlement.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.settlement.domain.SltAgreementApply;
import com.bonus.material.settlement.service.ISltAgreementApplyService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 结算协议申请Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "结算协议申请接口")
@RestController
@RequestMapping("/slt_agreement_apply")
public class SltAgreementApplyController extends BaseController {
    @Autowired
    private ISltAgreementApplyService sltAgreementApplyService;

    /**
     * 查询结算协议申请列表
     */
    @ApiOperation(value = "查询结算协议申请列表")
    @RequiresPermissions("settlement:apply:list")
    @GetMapping("/list")
    public TableDataInfo list(SltAgreementApply sltAgreementApply) {
        startPage();
        List<SltAgreementApply> list = sltAgreementApplyService.selectSltAgreementApplyList(sltAgreementApply);
        return getDataTable(list);
    }

    /**
     * 导出结算协议申请列表
     */
    @ApiOperation(value = "导出结算协议申请列表")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:apply:export")
    @SysLog(title = "结算协议申请", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出结算协议申请")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SltAgreementApply sltAgreementApply) {
        List<SltAgreementApply> list = sltAgreementApplyService.selectSltAgreementApplyList(sltAgreementApply);
        ExcelUtil<SltAgreementApply> util = new ExcelUtil<SltAgreementApply>(SltAgreementApply.class);
        util.exportExcel(response, list, "结算协议申请数据");
    }

    /**
     * 获取结算协议申请详细信息
     */
    @ApiOperation(value = "获取结算协议申请详细信息")
    @RequiresPermissions("settlement:apply:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sltAgreementApplyService.selectSltAgreementApplyById(id));
    }

    /**
     * 新增结算协议申请
     */
    @ApiOperation(value = "新增结算协议申请")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:apply:add")
    @SysLog(title = "结算协议申请", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增结算协议申请")
    @PostMapping
    public AjaxResult add(@RequestBody SltAgreementApply sltAgreementApply) {
        try {
            return toAjax(sltAgreementApplyService.insertSltAgreementApply(sltAgreementApply));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改结算协议申请
     */
    @ApiOperation(value = "修改结算协议申请")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:apply:edit")
    @SysLog(title = "结算协议申请", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改结算协议申请")
    @PutMapping
    public AjaxResult edit(@RequestBody SltAgreementApply sltAgreementApply) {
        try {
            return toAjax(sltAgreementApplyService.updateSltAgreementApply(sltAgreementApply));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除结算协议申请
     */
    @ApiOperation(value = "删除结算协议申请")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:apply:remove")
    @SysLog(title = "结算协议申请", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除结算协议申请")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sltAgreementApplyService.deleteSltAgreementApplyByIds(ids));
    }
}
